"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var tslib_1 = require("tslib");
var core_1 = require("@ts-ioc/core");
var bootstrap_1 = require("@ts-ioc/bootstrap");
var path = require("path");
var platform_server_1 = require("@ts-ioc/platform-server");
var ConfigureFileLoader = /** @class */ (function () {
    function ConfigureFileLoader(baseURL, container) {
        this.baseURL = baseURL;
        this.container = container;
    }
    ConfigureFileLoader.prototype.load = function (uri) {
        return tslib_1.__awaiter(this, void 0, void 0, function () {
            var fs, cfgmodeles_1, cfgpath_1;
            return tslib_1.__generator(this, function (_a) {
                fs = require('fs');
                if (uri) {
                    if (fs.existsSync(uri)) {
                        return [2 /*return*/, require(uri)];
                    }
                    else if (fs.existsSync(path.join(this.baseURL, uri))) {
                        return [2 /*return*/, require(path.join(this.baseURL, uri))];
                    }
                    else {
                        console.log("config file: " + uri + " not exists.");
                        return [2 /*return*/, null];
                    }
                }
                else {
                    cfgpath_1 = path.join(this.baseURL, './config');
                    ['.js', '.ts', '.json'].forEach(function (ext) {
                        if (cfgmodeles_1) {
                            return false;
                        }
                        if (fs.existsSync(cfgpath_1 + ext)) {
                            cfgmodeles_1 = require(cfgpath_1 + ext);
                            return false;
                        }
                        return true;
                    });
                    return [2 /*return*/, cfgmodeles_1];
                }
                return [2 /*return*/];
            });
        });
    };
    ConfigureFileLoader.classAnnations = { "name": "ConfigureFileLoader", "params": { "constructor": ["baseURL", "container"], "load": ["uri"] } };
    ConfigureFileLoader = tslib_1.__decorate([
        core_1.Injectable(bootstrap_1.ConfigureLoaderToken),
        tslib_1.__metadata("design:paramtypes", [String, Object])
    ], ConfigureFileLoader);
    return ConfigureFileLoader;
}());
exports.ConfigureFileLoader = ConfigureFileLoader;
/**
 * server app.
 *
 * @export
 * @template T
 * @param {string} [baseURL]
 * @returns {IApplicationBuilderServer<T>}
 */
function serverApp(baseURL) {
    return new bootstrap_1.ApplicationBuilder(baseURL).use(ServerBootstrapModule);
}
exports.serverApp = serverApp;
var cwd = process.cwd();
var processRoot = path.join(path.dirname(cwd), path.basename(cwd));
/**
 * server boot module
 *
 * @export
 * @class ServerBootstrapModule
 */
var ServerBootstrapModule = /** @class */ (function () {
    function ServerBootstrapModule() {
    }
    ServerBootstrapModule.classAnnations = { "name": "ServerBootstrapModule", "params": {} };
    ServerBootstrapModule = tslib_1.__decorate([
        bootstrap_1.DIModule({
            imports: [
                platform_server_1.ServerModule,
                ConfigureFileLoader
            ],
            providers: [
                { provide: bootstrap_1.ProcessRunRootToken, useValue: processRoot }
            ],
            exports: [
                ConfigureFileLoader
            ]
        })
    ], ServerBootstrapModule);
    return ServerBootstrapModule;
}());
exports.ServerBootstrapModule = ServerBootstrapModule;

//# sourceMappingURL=sourcemaps/BootstrapModule.js.map
